==> wfmplan-1.2.0.tar.gz: wfmplan-1.2.0/README.md <==
# wfmplan

**Optimizing Workforce managemet planning :** Our Python library, wfmplan, is designed to streamline workforce planning across industries. It calculates the optimal number of agents required to meet SLA targets for expected incoming traffic, applicable in scenarios such as call centers, customer support, live chat, retail stores, and help desks. By analyzing expected customer interactions and SLA requirements, it enhances planning accuracy, reduces wait times, and improves operational efficiency.

## Features

- Calculate the number of agents required based on expected call volume, average handling time, and interval.
- Adjust for SLA or ASA (average speed of answer) targets.
- Account for maximum occupancy and shrinkage.
- Run optimization for a DataFrame containing multiple scenarios.

## Installation

You can install the library using pip:

```sh
pip install wfmplan
```

## Usage

Here's a basic example of how to use the `Optimizer` class:

```python
from wfmplan.AgentOptimizer import Optimizer

# Create an optimizer instance
optimizer = Optimizer(exp_vol=100, aht=300, interval=3600, method='asa', asa=20)

# Get the predicted agent requirements
result = optimizer.predict()

print(result)
```

For batch processing using the `BatchOptimizer` class, you can use the following example:

```python
from wfmplan.AgentOptimizer import BatchOptimizer
import pandas as pd

# Example usage
df = pd.DataFrame({
    'exp_vol': [1000, 1500, 2000],
    'exp_aht': [300, 200, 250],
    'interval_start': pd.to_datetime(['2024-06-01 08:00:00', '2024-06-01 09:00:00', '2024-06-01 10:00:00']),
    'interval_end': pd.to_datetime(['2024-06-01 09:00:00', '2024-06-01 10:00:00', '2024-06-01 11:00:00'])
})

operational_targets = {
    'max_occupancy': 0.95,
    'shrink': 0.1,
    'asa': 20,
    'method': 'asa'
}

batch_optimizer = BatchOptimizer(df, operational_targets)
result_df = batch_optimizer.run_optimization()

print(result_df)
```

For more details and advanced usage, refer to the [documentation](https://github.com/laddha-rishi/wfmplan).

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

---
If you're interested in collaborating to enhance the library further, please don't hesitate to contact me. This project is open source because I believe in empowering everyone and avoiding redundant work.

==> wfmplan-1.2.2.tar.gz: wfmplan-1.2.2/README.md <==
# wfmplan

**Optimizing Workforce managemet planning :** Our Python library, wfmplan, is designed to streamline workforce planning across industries. It calculates the optimal number of agents required to meet SLA targets for expected incoming traffic, applicable in scenarios such as call centers, customer support, live chat, retail stores, and help desks. By analyzing expected customer interactions and SLA requirements, it enhances planning accuracy, reduces wait times, and improves operational efficiency.

## Features

- Calculate the number of agents required based on expected call volume, average handling time, and interval.
- Adjust for SLA or ASA (average speed of answer) targets.
- Account for maximum occupancy and shrinkage.
- Run optimization for a DataFrame containing multiple scenarios.

## Installation

You can install the library using pip:

```sh
pip install wfmplan
```

## Usage

Here's a basic example of how to use the `Optimizer` class:

```python
from wfmplan.AgentOptimizer import Optimizer

# Create an optimizer instance
optimizer = Optimizer(exp_vol=100, aht=300, interval=3600, method='asa', asa=20)

# Get the predicted agent requirements
result = optimizer.predict()

print(result)
```

For batch processing using the `BatchOptimizer` class, you can use the following example:

```python
from wfmplan.AgentOptimizer import BatchOptimizer
import pandas as pd

# Example usage
df = pd.DataFrame({
    'exp_vol': [1000, 1500, 2000],
    'exp_aht': [300, 200, 250],
    'interval_start': pd.to_datetime(['2024-06-01 08:00:00', '2024-06-01 09:00:00', '2024-06-01 10:00:00']),
    'interval_end': pd.to_datetime(['2024-06-01 09:00:00', '2024-06-01 10:00:00', '2024-06-01 11:00:00'])
})

operational_targets = {
    'max_occupancy': 0.95,
    'shrink': 0.1,
    'asa': 20,
    'method': 'asa'
}

batch_optimizer = BatchOptimizer(df, operational_targets)
result_df = batch_optimizer.run_optimization()

print(result_df)
```

For more details and advanced usage, refer to the [documentation](https://medium.com/@laddha.rishi/queueing-up-success-revolutionize-workforce-planning-with-python-6c9d7edbb6cd).

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

---
If you're interested in collaborating to enhance the library further, please don't hesitate to contact me. This project is open source because I believe in empowering everyone and avoiding redundant work.
